/******************************************************************************
* Project Name		: CE95277 ADC and UART
* File Name			: main.c
* Version 			: **
* Device Used		: CY8C5888LTI-LP097
* Software Used		: PSoC Creator 3.1 SP2
* Compiler    		: ARM GCC 4.8.4, ARM RVDS Generic, ARM MDK Generic
* Related Hardware	: CY8CKIT059 PSoC 5 LP Prototyping Kit 
* Owner				: KLMZ
*
********************************************************************************
* Copyright (2015), Cypress Semiconductor Corporation. All Rights Reserved.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress)
* and is protected by and subject to worldwide patent protection (United
* States and foreign), United States copyright laws and international treaty
* provisions. Cypress hereby grants to licensee a personal, non-exclusive,
* non-transferable license to copy, use, modify, create derivative works of,
* and compile the Cypress Source Code and derivative works for the sole
* purpose of creating custom software in support of licensee product to be
* used only in conjunction with a Cypress integrated circuit as specified in
* the applicable agreement. Any reproduction, modification, translation,
* compilation, or representation of this software except as specified above 
* is prohibited without the express written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH 
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the 
* materials described herein. Cypress does not assume any liability arising out 
* of the application or use of any product or circuit described herein. Cypress 
* does not authorize its products for use as critical components in life-support 
* systems where a malfunction or failure may reasonably be expected to result in 
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of 
* such use and in doing so indemnifies Cypress against all charges. 
*
* Use of this Software may be limited by and subject to the applicable Cypress
* software license agreement. 
*******************************************************************************/

#include <device.h>
#include "stdio.h"

/* Project Defines */
#define FALSE  0
#define TRUE   1
#define TRANSMIT_BUFFER_SIZE  16

//    uint16 UART_1_GetByte(void) ;
//    uint8 UART_1_GetRxBufferSize(void)
typedef uint8 (*pfui8)();
typedef uint16 (*pfui16)();
typedef void (*pfv)();

//const int NUM_PORTS = 10;
#define NUM_PORTS 10
pfui16 const get_byte[NUM_PORTS] = {UART_2_GetByte,
    UART_3_GetByte,
    UART_4_GetByte,
    UART_5_GetByte,
    UART_6_GetByte,
    UART_7_GetByte,
    UART_8_GetByte,
    UART_9_GetByte,
    UART_10_GetByte,
    UART_11_GetByte};
pfui8 const get_size[NUM_PORTS] = {UART_2_GetRxBufferSize,
    UART_3_GetRxBufferSize,
    UART_4_GetRxBufferSize,
    UART_5_GetRxBufferSize,
    UART_6_GetRxBufferSize,
    UART_7_GetRxBufferSize,
    UART_8_GetRxBufferSize,
    UART_9_GetRxBufferSize,
    UART_10_GetRxBufferSize,
    UART_11_GetRxBufferSize};
pfv const uart_start[NUM_PORTS] = {UART_2_Start,
    UART_3_Start,
    UART_4_Start,
    UART_5_Start,
    UART_6_Start,
    UART_7_Start,
    UART_8_Start,
    UART_9_Start,
    UART_10_Start,
    UART_11_Start};

#define UART_BUFFER_SIZE 100
struct UARTBuffer
{
    int size;
    uint8 data[UART_BUFFER_SIZE];
};

struct UARTBuffer uart_buffer[NUM_PORTS];

void init_uarts()
{
    int n;
    for (n=0;n<NUM_PORTS; n++)
    {
        uart_buffer[n].size = 0;
        uart_start[n]();
    }

}

int num_overruns = 0;
void uarts_read_new_data()
{
    uint16 b = 0;
    int n;
    for (n=0;n<NUM_PORTS; n++)
    {
        while (get_size[n]())
        {
            b = get_byte[n]();
            if ((b>>8)&(UART_2_RX_STS_OVERRUN|UART_2_RX_STS_SOFT_BUFF_OVER)) // the values are all the same. why isn't there one constant for them?
            {
                UART_1_PutString("\nOverrun!!\n");
                num_overruns++;
            }
            uart_buffer[n].data[uart_buffer[n].size] = b;
            uart_buffer[n].size++;
        }
    }
}

void tx_most_data()
{
    int most = 0;
    int mostn = 0;
    int n;
    for (n=0;n<NUM_PORTS; n++)
    {
        if (uart_buffer[n].size > most)
        {
            most = uart_buffer[n].size;
            mostn = n;
        }
    }
    
    if (most > 0)
    {
        //!!!! TX can block if the TX buffer is full
        UART_1_PutChar('\n');
        UART_1_PutChar(mostn+'0');
        UART_1_PutChar(uart_buffer[mostn].size+'!');
        UART_1_PutArray(uart_buffer[mostn].data, uart_buffer[mostn].size);
        uart_buffer[mostn].size = 0;
    }
    else
    {
        // tx buffer is empty, send status
        if (UART_1_GetTxBufferSize() == 0)
        {
            char buf[32];
            sprintf(buf, "num overrruns:%d\n", num_overruns);
            UART_1_PutString(buf);
        }
    }
}

/*******************************************************************************
* Function Name: main
********************************************************************************
*
* Summary:
*  main() performs following functions:
*  1: Starts the ADC and UART components.
*  2: Checks for ADC end of conversion.  Stores latest result in output
*     if conversion complete.
*  3: Checks for UART input.
*     On 'C' or 'c' received: transmits the last sample via the UART.
*     On 'S' or 's' received: continuously transmits samples as they are completed.
*     On 'X' or 'x' received: stops continuously transmitting samples.
*     On 'E' or 'e' received: transmits a dummy byte of data.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
int main()
{
    /* Variable to store ADC result */
    uint32 Output;
    /* Variable to store UART received character */
    uint8 Ch;
    /* Variable used to send emulated data */
    uint8 EmulatedData;
    /* Flags used to store transmit data commands */
    uint8 ContinuouslySendData;
    uint8 SendSingleByte;
    uint8 SendEmulatedData;
    /* Transmit Buffer */
    char TransmitBuffer[TRANSMIT_BUFFER_SIZE];
    
    CyGlobalIntEnable; 
    isr_1_Start();      /* Initializing the ISR */

    //Clock_1_SetDivider(26-1);
    //Clock_2_SetDivider(26-1);
    
    /* Start the components */
    //ADC_DelSig_1_Start();
    
    UART_1_Start();
    init_uarts();
    
    /* Initialize Variables */
    ContinuouslySendData = FALSE;
    SendSingleByte = FALSE;
    SendEmulatedData = FALSE;
    EmulatedData = 0;
    
    /* Start the ADC conversion */
    //ADC_DelSig_1_StartConvert();
    
    /* Send message to verify COM port is connected properly */
    UART_1_PutString("\nCOM Port Open!!\n");
    int v = Clock_1_GetDividerRegister();
    sprintf(TransmitBuffer, "%d", v);
    UART_1_PutString(TransmitBuffer);
    for(;;)
    {
        uarts_read_new_data();
        tx_most_data();
        
        /* Non-blocking call to get the latest data recieved  */
        Ch = 0;//UART_1_GetChar();
        
        
        /* Set flags based on UART command */
        switch(Ch)
        {
            case 0:
                /* No new data was recieved */
                break;
            case '2':
                UART_1_PutString("Test:");
            case '1':
                {
                    int n;
                    for (n=0;n<10;n++)
                        uart_buffer[0].data[n] = '0'+n;
                    uart_buffer[0].size = 10;
                }
                break;
            case 'C':
            case 'c':
                SendSingleByte = TRUE;
                break;
            case 'S':
            case 's':
                ContinuouslySendData = TRUE;
                break;
            case 'X':
            case 'x':
                ContinuouslySendData = FALSE;
                break;
            case 'E':
            case 'e':
                SendEmulatedData = TRUE;
                break;
            default:
                /* Place error handling code here */
                break;    
        }
        
        
    }
    return 0;
}


/* [] END OF FILE */
